==> jc-1.4.5.tar.gz: javax/swing/plaf/metal/MetalComboBoxUI.h <==
// public class javax.swing.plaf.metal.MetalComboBoxUI

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b5646fddc98e0bec javax_swing_plaf_ComboBoxUI
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI
// @dep_class 34a0355fa10e18d2 javax_swing_plaf_basic_BasicComboBoxUI
// @dep_class 3c0a200e7cc4efe9 javax_swing_plaf_metal_MetalComboBoxUI

// header file dependencies
// @dep_header javax_swing_plaf_basic_BasicComboBoxUI

#include "javax/swing/plaf/basic/BasicComboBoxUI.h"

#ifndef _JC_javax_swing_plaf_metal_MetalComboBoxUI_H_
#define _JC_javax_swing_plaf_metal_MetalComboBoxUI_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JComponent$object;
struct _jc_javax_swing_plaf_ComponentUI$object;
struct _jc_javax_swing_plaf_metal_MetalComboBoxUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_metal_MetalComboBoxUI$sub_refs	_jc_javax_swing_plaf_metal_MetalComboBoxUI$sub_refs;
typedef struct _jc_javax_swing_plaf_metal_MetalComboBoxUI$sub_nonrefs	_jc_javax_swing_plaf_metal_MetalComboBoxUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_metal_MetalComboBoxUI$refs	_jc_javax_swing_plaf_metal_MetalComboBoxUI$refs;
typedef struct _jc_javax_swing_plaf_metal_MetalComboBoxUI$nonrefs	_jc_javax_swing_plaf_metal_MetalComboBoxUI$nonrefs;
typedef struct _jc_javax_swing_plaf_metal_MetalComboBoxUI$object	_jc_javax_swing_plaf_metal_MetalComboBoxUI$object;

typedef struct _jc_javax_swing_plaf_metal_MetalComboBoxUI$fields_struct	_jc_javax_swing_plaf_metal_MetalComboBoxUI$fields_struct;
typedef const struct _jc_javax_swing_plaf_metal_MetalComboBoxUI$vmethods	_jc_javax_swing_plaf_metal_MetalComboBoxUI$vmethods;
typedef const struct _jc_javax_swing_plaf_metal_MetalComboBoxUI$vtable	_jc_javax_swing_plaf_metal_MetalComboBoxUI$vtable;
typedef const struct _jc_javax_swing_plaf_metal_MetalComboBoxUI$vtype	_jc_javax_swing_plaf_metal_MetalComboBoxUI$vtype;

// Class fields structure
struct _jc_javax_swing_plaf_metal_MetalComboBoxUI$fields_struct {
	struct _jc_javax_swing_plaf_metal_MetalComboBoxUI$object	*instance;
};
extern _jc_javax_swing_plaf_metal_MetalComboBoxUI$fields_struct _jc_javax_swing_plaf_metal_MetalComboBoxUI$class_fields;

// Constructors
extern void _jc_javax_swing_plaf_metal_MetalComboBoxUI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_metal_MetalComboBoxUI$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_javax_swing_plaf_metal_MetalComboBoxUI$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_javax_swing_plaf_ComponentUI$object *_jc_javax_swing_plaf_metal_MetalComboBoxUI$method$createUI$32e25151aaddad9d(_jc_env *, struct _jc_javax_swing_JComponent$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_plaf_metal_MetalComboBoxUI$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_metal_MetalComboBoxUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_ComboBoxUI$vmethods	javax_swing_plaf_ComboBoxUI;
	_jc_javax_swing_plaf_basic_BasicComboBoxUI$vmethods	javax_swing_plaf_basic_BasicComboBoxUI;
	_jc_javax_swing_plaf_metal_MetalComboBoxUI$vmethods	javax_swing_plaf_metal_MetalComboBoxUI;
};

// Vtype
struct _jc_javax_swing_plaf_metal_MetalComboBoxUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_metal_MetalComboBoxUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_metal_MetalComboBoxUI$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_metal_MetalComboBoxUI$refs {
    _jc_javax_swing_plaf_metal_MetalComboBoxUI$sub_refs	javax_swing_plaf_metal_MetalComboBoxUI;
    _jc_javax_swing_plaf_basic_BasicComboBoxUI$sub_refs	javax_swing_plaf_basic_BasicComboBoxUI;
    _jc_javax_swing_plaf_ComboBoxUI$sub_refs	javax_swing_plaf_ComboBoxUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_metal_MetalComboBoxUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_metal_MetalComboBoxUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_ComboBoxUI$sub_nonrefs	javax_swing_plaf_ComboBoxUI;
    _jc_javax_swing_plaf_basic_BasicComboBoxUI$sub_nonrefs	javax_swing_plaf_basic_BasicComboBoxUI;
    _jc_javax_swing_plaf_metal_MetalComboBoxUI$sub_nonrefs	javax_swing_plaf_metal_MetalComboBoxUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_metal_MetalComboBoxUI$object {
	_jc_javax_swing_plaf_metal_MetalComboBoxUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_metal_MetalComboBoxUI$vtype	*vtype;
	_jc_javax_swing_plaf_metal_MetalComboBoxUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_metal_MetalComboBoxUI$vtype _jc_javax_swing_plaf_metal_MetalComboBoxUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_metal_MetalComboBoxUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_metal_MetalComboBoxUI$class_object;

#endif	/* _JC_javax_swing_plaf_metal_MetalComboBoxUI_H_ */

==> jc-1.4.6.tar.gz: javax/swing/plaf/metal/MetalComboBoxUI.h <==
// public class javax.swing.plaf.metal.MetalComboBoxUI

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b5646fddc98e0bec javax_swing_plaf_ComboBoxUI
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI
// @dep_class 34a0355fa10e18d2 javax_swing_plaf_basic_BasicComboBoxUI
// @dep_class b1711b5983d0ebb0 javax_swing_plaf_metal_MetalComboBoxUI

// header file dependencies
// @dep_header javax_swing_plaf_basic_BasicComboBoxUI

#include "javax/swing/plaf/basic/BasicComboBoxUI.h"

#ifndef _JC_javax_swing_plaf_metal_MetalComboBoxUI_H_
#define _JC_javax_swing_plaf_metal_MetalComboBoxUI_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_HashMap$object;
struct _jc_javax_swing_JComponent$object;
struct _jc_javax_swing_plaf_ComponentUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_metal_MetalComboBoxUI$sub_refs	_jc_javax_swing_plaf_metal_MetalComboBoxUI$sub_refs;
typedef struct _jc_javax_swing_plaf_metal_MetalComboBoxUI$sub_nonrefs	_jc_javax_swing_plaf_metal_MetalComboBoxUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_metal_MetalComboBoxUI$refs	_jc_javax_swing_plaf_metal_MetalComboBoxUI$refs;
typedef struct _jc_javax_swing_plaf_metal_MetalComboBoxUI$nonrefs	_jc_javax_swing_plaf_metal_MetalComboBoxUI$nonrefs;
typedef struct _jc_javax_swing_plaf_metal_MetalComboBoxUI$object	_jc_javax_swing_plaf_metal_MetalComboBoxUI$object;

typedef struct _jc_javax_swing_plaf_metal_MetalComboBoxUI$fields_struct	_jc_javax_swing_plaf_metal_MetalComboBoxUI$fields_struct;
typedef const struct _jc_javax_swing_plaf_metal_MetalComboBoxUI$vmethods	_jc_javax_swing_plaf_metal_MetalComboBoxUI$vmethods;
typedef const struct _jc_javax_swing_plaf_metal_MetalComboBoxUI$vtable	_jc_javax_swing_plaf_metal_MetalComboBoxUI$vtable;
typedef const struct _jc_javax_swing_plaf_metal_MetalComboBoxUI$vtype	_jc_javax_swing_plaf_metal_MetalComboBoxUI$vtype;

// Class fields structure
struct _jc_javax_swing_plaf_metal_MetalComboBoxUI$fields_struct {
	struct _jc_java_util_HashMap$object	*instances;
};
extern _jc_javax_swing_plaf_metal_MetalComboBoxUI$fields_struct _jc_javax_swing_plaf_metal_MetalComboBoxUI$class_fields;

// Constructors
extern void _jc_javax_swing_plaf_metal_MetalComboBoxUI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_metal_MetalComboBoxUI$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_javax_swing_plaf_metal_MetalComboBoxUI$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_javax_swing_plaf_ComponentUI$object *_jc_javax_swing_plaf_metal_MetalComboBoxUI$method$createUI$32e25151aaddad9d(_jc_env *, struct _jc_javax_swing_JComponent$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_plaf_metal_MetalComboBoxUI$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_metal_MetalComboBoxUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_ComboBoxUI$vmethods	javax_swing_plaf_ComboBoxUI;
	_jc_javax_swing_plaf_basic_BasicComboBoxUI$vmethods	javax_swing_plaf_basic_BasicComboBoxUI;
	_jc_javax_swing_plaf_metal_MetalComboBoxUI$vmethods	javax_swing_plaf_metal_MetalComboBoxUI;
};

// Vtype
struct _jc_javax_swing_plaf_metal_MetalComboBoxUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_metal_MetalComboBoxUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_metal_MetalComboBoxUI$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_metal_MetalComboBoxUI$refs {
    _jc_javax_swing_plaf_metal_MetalComboBoxUI$sub_refs	javax_swing_plaf_metal_MetalComboBoxUI;
    _jc_javax_swing_plaf_basic_BasicComboBoxUI$sub_refs	javax_swing_plaf_basic_BasicComboBoxUI;
    _jc_javax_swing_plaf_ComboBoxUI$sub_refs	javax_swing_plaf_ComboBoxUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_metal_MetalComboBoxUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_metal_MetalComboBoxUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_ComboBoxUI$sub_nonrefs	javax_swing_plaf_ComboBoxUI;
    _jc_javax_swing_plaf_basic_BasicComboBoxUI$sub_nonrefs	javax_swing_plaf_basic_BasicComboBoxUI;
    _jc_javax_swing_plaf_metal_MetalComboBoxUI$sub_nonrefs	javax_swing_plaf_metal_MetalComboBoxUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_metal_MetalComboBoxUI$object {
	_jc_javax_swing_plaf_metal_MetalComboBoxUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_metal_MetalComboBoxUI$vtype	*vtype;
	_jc_javax_swing_plaf_metal_MetalComboBoxUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_metal_MetalComboBoxUI$vtype _jc_javax_swing_plaf_metal_MetalComboBoxUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_metal_MetalComboBoxUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_metal_MetalComboBoxUI$class_object;

#endif	/* _JC_javax_swing_plaf_metal_MetalComboBoxUI_H_ */
